@@ -37,6 +37,7 @@
 #include <libgnomeui/gnome-client.h>
 #include <string.h>
 #include <stdlib.h>
+#include <gtkmozembed.h>
 
 #include "GNOME_Yelp.h"
 #include "yelp-window.h"
@@ -251,7 +252,7 @@ main_save_session (GnomeClient        *client,
 			urls = tmp;
 		}
 
-		argv[2] = g_strconcat (urls, "\"", NULL);
+		argv[arg_len - 1] = g_strconcat (urls, "\"", NULL);
 		g_free (urls);
 	}
 
@@ -286,12 +287,13 @@ main_restore_session (void)
         }
 
 	if (open_urls) {
-		gchar **urls = g_strsplit (open_urls, ";", -1);
+		gchar **urls = g_strsplit_set (open_urls, ";\"", -1);
 		gchar *url;
 		gint   i = 0;
 		
 		while ((url = urls[i]) != NULL) {
-			main_open_new_window (yelp_base, url);
+			if (*url != '\0')
+				main_open_new_window (yelp_base, url);
 			++i;
 		}
 		
@@ -321,6 +323,8 @@ main (int argc, char **argv)
 				      GNOME_PARAM_POPT_TABLE, options,
 				      GNOME_PROGRAM_STANDARD_PROPERTIES,
 				      NULL);
+	g_set_application_name (_("Help"));
+	gtk_window_set_default_icon_name ("gnome-help");
 
 	/* Need to set this to the canonical DISPLAY value, since
 	   that's where we're registering per-display components */
@@ -329,6 +333,8 @@ main (int argc, char **argv)
 		 gdk_display_get_name (gdk_display_get_default ()) );
 
 	gnome_vfs_init ();
+
+	gtk_moz_embed_set_comp_path (MOZILLA_HOME);
 	
 	/* Commandline parsing is done here */
 	g_object_get (G_OBJECT (program),
