@@ -68,7 +68,9 @@ typedef enum {
     YELP_ICON_BLOCKQUOTE = 0,
     YELP_ICON_CAUTION,
     YELP_ICON_IMPORTANT,
+    YELP_ICON_NEXT,
     YELP_ICON_NOTE,
+    YELP_ICON_PREVIOUS,
     YELP_ICON_PROGRAMLISTING,
     YELP_ICON_TIP,
     YELP_ICON_WARNING,
